'use strict';

const sentry = require('../../../lib/sentry');
const pino = require('../../../lib/pino');
const db = require('../../../config/db');

let pages;
function updatePagesRegistry() {
    db.map('SELECT wiki, data FROM wikidot_pages_lists', {}, ({wiki, data}) => ({wiki, list: data.list}))
        .then((results) => {
            pages = {};
            results.forEach(({wiki, list}) => {
                list.forEach((pageName) => {
                    if (pages[pageName]) {
                        pages[pageName].push(wiki);
                    } else {
                        pages[pageName] = [wiki];
                    }
                });
            });
            pino.info('Pages lists registry updated');
        })
        .catch((error) => {
            pino.error(error, 'Error occured during pages list registry update');
            sentry.captureException(error);
        });

    setTimeout(() => {
        updatePagesRegistry();
    }, 1000 * 60 * 30); // 30 min
}
updatePagesRegistry();

exports.getWikiListByPageName = (name) => pages[name] || [];
