'use strict';

const sentry = require('../../lib/sentry');
const pino = require('../../lib/pino');
const wk = require('../../config/wikidot-kit');
const db = require('../../config/db');
const Promise = require('bluebird');

const PAGES_BLACKLIST = ['admin:manage', 'nav:side', 'nav:top'];

module.exports = async function importPageRevisions({wikiName, pageName}) {
    if (PAGES_BLACKLIST.includes(pageName)) {
        return Promise.resolve();
    }
    const wiki = wk.wiki[wikiName];
    const wikiURL = wiki.url;
    const revisions = await wk.fetchPageRevisionsList({wikiURL, pageName});

    return Promise.resolve(revisions)
        .map((revision) => {
            return wk.fetchPageRevisionContent({wikiURL, revisionID: revision.id})
                .then((content) => {
                    revision.content = content;
                    return db.query(`
                            INSERT INTO page_revisions (id, name, wiki, data) VALUES ($(id), $(name), $(wiki), $(data))
                            ON CONFLICT (id) DO UPDATE SET
                                name = $(name),
                                wiki = $(wiki),
                                data = $(data);
                        `, {id: revision.id, name: pageName, wiki: wikiName, data: revision})
                        .catch((error) => {
                            pino.error(error, 'Error saving page revisions');
                            sentry.captureException(error, {extra: {wiki: wikiName, name: pageName}});
                        });
                });
        }, {concurrency: 1});
};
